@@ -1,17 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
-
 from django.contrib.auth.models import User
 from django.db import models
-from django.utils.translation import gettext_lazy
 
 
 class Author(models.Model):
     name = models.CharField(max_length=100,
             help_text = u"Имя автора")
-    user = models.ForeignKey(User,
-            help_text = gettext_lazy('User')
-            )
+    user = models.ForeignKey(User)
 
 
 class Publisher(models.Model):
@@ -20,6 +16,11 @@ class Publisher(models.Model):
 
 class Book(models.Model):
     title = models.CharField(max_length=100)
+    status = models.IntegerField(choices=(
+        (1, 'new'),
+        (2, 'published'),
+        (3, 'archived'),
+    ))
     author = models.ForeignKey(Author)
     price = models.PositiveIntegerField(default=0, blank=True)
     publisher = models.ForeignKey(Publisher, null=True, blank=True)
