@@ -13,3 +13,10 @@ DEBUG = TEMPLATE_DEBUG = True
 CACHE_BACKEND = 'locmem://'
 ADREST_ACCESS_LOG = True
 ADREST_ALLOW_OPTIONS = True
+ADREST_AUTO_CREATE_ACCESSKEY = True
+TEMPLATE_CONTEXT_PROCESSORS = (
+    'django.core.context_processors.static',
+    'django.core.context_processors.request',
+    'django.contrib.auth.context_processors.auth',
+)
+
