@@ -1,10 +1,10 @@
 from adrest.tests.utils import AdrestTestCase
-from adrest.tests.simple.api import API, TaskResource
+from adrest.tests.simple.api import API
 
 
 class SimpleTestCase(AdrestTestCase):
     api = API
 
     def test_base(self):
-        response = self.get_resource(TaskResource)
+        response = self.get_resource('task')
         self.assertContains(response, 'true')
